@@ -35,13 +35,11 @@
 #include <glib/gi18n-lib.h>
 #include <gnome-keyring-memory.h>
 #include <nm-setting-connection.h>
-#include <nm-setting-8021x.h>
 
 #include "auth-helpers.h"
 #include "nm-openvpn.h"
 #include "src/nm-openvpn-service.h"
 #include "common-gnome/keyring-helpers.h"
-#include "common/utils.h"
 
 static void
 show_password (GtkToggleButton *togglebutton, GtkEntry *password_entry)
@@ -131,47 +129,6 @@ fill_vpn_passwords (GladeXML *xml,
 	}
 }
 
-static void
-tls_cert_changed_cb (GtkWidget *widget, GtkWidget *next_widget)
-{
-	GtkFileChooser *this, *next;
-	char *fname, *next_fname;
-
-	/* If the just-changed file chooser is a PKCS#12 file, then all of the
-	 * TLS filechoosers have to be PKCS#12.  But if it just changed to something
-	 * other than a PKCS#12 file, then clear out the other file choosers.
-	 *
-	 * Basically, all the choosers have to contain PKCS#12 files, or none of
-	 * them can, because PKCS#12 files contain everything required for the TLS
-	 * connection (CA, client cert, private key).
-	 */
-
-	this = GTK_FILE_CHOOSER (widget);
-	next = GTK_FILE_CHOOSER (next_widget);
-
-	fname = gtk_file_chooser_get_filename (this);
-	if (is_pkcs12 (fname)) {
-		/* Make sure all choosers have this PKCS#12 file */
-		next_fname = gtk_file_chooser_get_filename (next);
-		if (!next_fname || strcmp (fname, next_fname)) {
-			/* Next chooser was different, make it the same as the first */
-			gtk_file_chooser_set_filename (next, fname);
-		}
-		g_free (fname);
-		g_free (next_fname);
-		return;
-	}
-	g_free (fname);
-
-	/* Just-chosen file isn't PKCS#12 or no file was chosen, so clear out other
-	 * file selectors that have PKCS#12 files in them.
-	 */
-	next_fname = gtk_file_chooser_get_filename (next);
-	if (is_pkcs12 (next_fname))
-		gtk_file_chooser_set_filename (next, NULL);
-	g_free (next_fname);
-}
-
 void
 tls_pw_init_auth_widget (GladeXML *xml,
                          GtkSizeGroup *group,
@@ -181,7 +138,7 @@ tls_pw_init_auth_widget (GladeXML *xml,
                          ChangedCallback changed_cb,
                          gpointer user_data)
 {
-	GtkWidget *widget, *ca, *cert, *key;
+	GtkWidget *widget;
 	const char *value;
 	char *tmp;
 	GtkFileFilter *filter;
@@ -192,68 +149,59 @@ tls_pw_init_auth_widget (GladeXML *xml,
 	g_return_if_fail (prefix != NULL);
 
 	tmp = g_strdup_printf ("%s_ca_cert_chooser", prefix);
-	ca = glade_xml_get_widget (xml, tmp);
+	widget = glade_xml_get_widget (xml, tmp);
 	g_free (tmp);
 
-	gtk_size_group_add_widget (group, ca);
-	if (!strcmp (contype, NM_OPENVPN_CONTYPE_TLS) || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD_TLS))
-		filter = tls_file_chooser_filter_new (TRUE);
-	else
-		filter = tls_file_chooser_filter_new (FALSE);
-
-	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (ca), filter);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (ca), TRUE);
-	gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (ca),
+	gtk_size_group_add_widget (group, widget);
+	filter = tls_file_chooser_filter_new ();
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (widget), filter);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (widget), TRUE);
+	gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (widget),
 	                                   _("Choose a Certificate Authority certificate..."));
-	g_signal_connect (G_OBJECT (ca), "selection-changed", G_CALLBACK (changed_cb), user_data);
+	g_signal_connect (G_OBJECT (widget), "selection-changed", G_CALLBACK (changed_cb), user_data);
 
 	if (s_vpn) {
 		value = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_CA);
 		if (value && strlen (value))
-			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (ca), value);
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (widget), value);
 	}
 
 	if (!strcmp (contype, NM_OPENVPN_CONTYPE_TLS) || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD_TLS)) {
 		tmp = g_strdup_printf ("%s_user_cert_chooser", prefix);
-		cert = glade_xml_get_widget (xml, tmp);
+		widget = glade_xml_get_widget (xml, tmp);
 		g_free (tmp);
 
-		gtk_size_group_add_widget (group, cert);
-		filter = tls_file_chooser_filter_new (TRUE);
-		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (cert), filter);
-		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (cert), TRUE);
-		gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (cert),
+		gtk_size_group_add_widget (group, widget);
+		filter = tls_file_chooser_filter_new ();
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (widget), filter);
+		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (widget), TRUE);
+		gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (widget),
 		                                   _("Choose your personal certificate..."));
-		g_signal_connect (G_OBJECT (cert), "selection-changed", G_CALLBACK (changed_cb), user_data);
+		g_signal_connect (G_OBJECT (widget), "selection-changed", G_CALLBACK (changed_cb), user_data);
 
 		if (s_vpn) {
 			value = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_CERT);
 			if (value && strlen (value))
-				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (cert), value);
+				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (widget), value);
 		}
 
 		tmp = g_strdup_printf ("%s_private_key_chooser", prefix);
-		key = glade_xml_get_widget (xml, tmp);
+		widget = glade_xml_get_widget (xml, tmp);
 		g_free (tmp);
 
-		gtk_size_group_add_widget (group, key);
-		filter = tls_file_chooser_filter_new (TRUE);
-		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (key), filter);
-		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (key), TRUE);
-		gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (key),
+		gtk_size_group_add_widget (group, widget);
+		filter = tls_file_chooser_filter_new ();
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (widget), filter);
+		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (widget), TRUE);
+		gtk_file_chooser_button_set_title (GTK_FILE_CHOOSER_BUTTON (widget),
 		                                   _("Choose your private key..."));
-		g_signal_connect (G_OBJECT (key), "selection-changed", G_CALLBACK (changed_cb), user_data);
+		g_signal_connect (G_OBJECT (widget), "selection-changed", G_CALLBACK (changed_cb), user_data);
 
 		if (s_vpn) {
 			value = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_KEY);
 			if (value && strlen (value))
-				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (key), value);
+				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (widget), value);
 		}
-
-		/* Link choosers to the PKCS#12 changer callback */
-		g_signal_connect (ca, "selection-changed", G_CALLBACK (tls_cert_changed_cb), cert);
-		g_signal_connect (cert, "selection-changed", G_CALLBACK (tls_cert_changed_cb), key);
-		g_signal_connect (key, "selection-changed", G_CALLBACK (tls_cert_changed_cb), ca);
 	}
 
 	if (!strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD) || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD_TLS)) {
@@ -369,23 +317,19 @@ validate_file_chooser (GladeXML *xml, const char *name)
 {
 	GtkWidget *widget;
 	char *str;
-	gboolean valid = FALSE;
 
 	widget = glade_xml_get_widget (xml, name);
 	str = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
-	if (str && strlen (str))
-		valid = TRUE;
-	g_free (str);
-	return valid;
+	if (!str || !strlen (str))
+		return FALSE;
+	return TRUE;
 }
 
 static gboolean
 validate_tls (GladeXML *xml, const char *prefix, GError **error)
 {
 	char *tmp;
-	gboolean valid, encrypted = FALSE;
-	GtkWidget *widget;
-	char *str;
+	gboolean valid;
 
 	tmp = g_strdup_printf ("%s_ca_cert_chooser", prefix);
 	valid = validate_file_chooser (xml, tmp);
@@ -410,7 +354,6 @@ validate_tls (GladeXML *xml, const char *prefix, GError **error)
 	}
 
 	tmp = g_strdup_printf ("%s_private_key_chooser", prefix);
-	widget = glade_xml_get_widget (xml, tmp);
 	valid = validate_file_chooser (xml, tmp);
 	g_free (tmp);
 	if (!valid) {
@@ -421,24 +364,6 @@ validate_tls (GladeXML *xml, const char *prefix, GError **error)
 		return FALSE;
 	}
 
-	/* Encrypted certificates require a password */
-	str = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
-	encrypted = is_pkcs12 (str) || is_encrypted_pem (str);
-	g_free (str);
-	if (encrypted) {
-		tmp = g_strdup_printf ("%s_private_key_password_entry", prefix);
-		widget = glade_xml_get_widget (xml, tmp);
-		g_free (tmp);
-
-		if (!gtk_entry_get_text_length (GTK_ENTRY (widget))) {
-			g_set_error (error,
-			             OPENVPN_PLUGIN_UI_ERROR,
-			             OPENVPN_PLUGIN_UI_ERROR_INVALID_PROPERTY,
-			             NM_OPENVPN_KEY_CERTPASS);
-			return FALSE;
-		}
-	}
-
 	return TRUE;
 }
 
@@ -536,8 +461,12 @@ update_from_filechooser (GladeXML *xml,
 	g_free (tmp);
 
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
-	if (filename && strlen (filename))
+	if (!filename)
+		return;
+
+	if (strlen (filename))
 		nm_setting_vpn_add_data_item (s_vpn, key, filename);
+	
 	g_free (filename);
 }
 
@@ -701,7 +630,6 @@ tls_default_filter (const GtkFileFilterInfo *filter_info, gpointer data)
 	char *contents = NULL, *p, *ext;
 	gsize bytes_read = 0;
 	gboolean show = FALSE;
-	gboolean pkcs_allowed = GPOINTER_TO_UINT (data);
 	struct stat statbuf;
 
 	if (!filter_info->filename)
@@ -714,12 +642,6 @@ tls_default_filter (const GtkFileFilterInfo *filter_info, gpointer data)
 	ext = g_ascii_strdown (p, -1);
 	if (!ext)
 		return FALSE;
-
-	if (pkcs_allowed && !strcmp (ext, ".p12") && is_pkcs12 (filter_info->filename)) {
-		g_free (ext);
-		return TRUE;
-	}
-
 	if (strcmp (ext, ".pem") && strcmp (ext, ".crt") && strcmp (ext, ".key") && strcmp (ext, ".cer")) {
 		g_free (ext);
 		return FALSE;
@@ -760,14 +682,13 @@ out:
 }
 
 GtkFileFilter *
-tls_file_chooser_filter_new (gboolean pkcs_allowed)
+tls_file_chooser_filter_new (void)
 {
 	GtkFileFilter *filter;
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_add_custom (filter, GTK_FILE_FILTER_FILENAME, tls_default_filter, GUINT_TO_POINTER (pkcs_allowed), NULL);
-	gtk_file_filter_set_name (filter, pkcs_allowed ? _("PEM or PKCS#12 certificates (*.pem, *.crt, *.key, *.cer, *.p12)")
-	                                               : _("PEM certificates (*.pem, *.crt, *.key, *.cer)"));
+	gtk_file_filter_add_custom (filter, GTK_FILE_FILTER_FILENAME, tls_default_filter, NULL, NULL);
+	gtk_file_filter_set_name (filter, _("PEM certificates (*.pem, *.crt, *.key, *.cer)"));
 	return filter;
 }
 
@@ -834,9 +755,6 @@ sk_file_chooser_filter_new (void)
 static const char *advanced_keys[] = {
 	NM_OPENVPN_KEY_PORT,
 	NM_OPENVPN_KEY_COMP_LZO,
-	NM_OPENVPN_KEY_MSSFIX,
-	NM_OPENVPN_KEY_TUNNEL_MTU,
-	NM_OPENVPN_KEY_FRAGMENT_SIZE,
 	NM_OPENVPN_KEY_TAP_DEV,
 	NM_OPENVPN_KEY_PROTO_TCP,
 	NM_OPENVPN_KEY_CIPHER,
@@ -886,26 +804,6 @@ port_toggled_cb (GtkWidget *check, gpointer user_data)
 	gtk_widget_set_sensitive (widget, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
 }
 
-static void
-tunmtu_toggled_cb (GtkWidget *check, gpointer user_data)
-{
-	GladeXML *xml = (GladeXML *) user_data;
-	GtkWidget *widget;
-
-	widget = glade_xml_get_widget (xml, "tunmtu_spinbutton");
-	gtk_widget_set_sensitive (widget, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
-}
-
-static void
-fragment_toggled_cb (GtkWidget *check, gpointer user_data)
-{
-	GladeXML *xml = (GladeXML *) user_data;
-	GtkWidget *widget;
-
-	widget = glade_xml_get_widget (xml, "fragment_spinbutton");
-	gtk_widget_set_sensitive (widget, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
-}
-
 static void
 reneg_toggled_cb (GtkWidget *check, gpointer user_data)
 {
@@ -1032,11 +930,6 @@ populate_hmacauth_combo (GtkComboBox *box, const char *hmacauth)
 		NM_OPENVPN_AUTH_NONE,
 		NM_OPENVPN_AUTH_MD5,
 		NM_OPENVPN_AUTH_SHA1,
-		NM_OPENVPN_AUTH_SHA224,
-		NM_OPENVPN_AUTH_SHA256,
-		NM_OPENVPN_AUTH_SHA384,
-		NM_OPENVPN_AUTH_SHA512,
-		NM_OPENVPN_AUTH_RIPEMD160,
 		NULL
 	};
 
@@ -1059,16 +952,6 @@ populate_hmacauth_combo (GtkComboBox *box, const char *hmacauth)
 			name = _("MD-5");
 		else if (!strcmp (*item, NM_OPENVPN_AUTH_SHA1))
 			name = _("SHA-1");
-		else if (!strcmp (*item, NM_OPENVPN_AUTH_SHA224))
-			name = _("SHA-224");
-		else if (!strcmp (*item, NM_OPENVPN_AUTH_SHA256))
-			name = _("SHA-256");
-		else if (!strcmp (*item, NM_OPENVPN_AUTH_SHA384))
-			name = _("SHA-384");
-		else if (!strcmp (*item, NM_OPENVPN_AUTH_SHA512))
-			name = _("SHA-512");
-		else if (!strcmp (*item, NM_OPENVPN_AUTH_RIPEMD160))
-			name = _("RIPEMD-160");
 		else
 			g_assert_not_reached ();
 
@@ -1189,73 +1072,12 @@ advanced_dialog_new (GHashTable *hash, const char *contype)
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
 
-	widget = glade_xml_get_widget (xml, "tunmtu_checkbutton");
-	g_assert (widget);
-	g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (tunmtu_toggled_cb), xml);
-
-	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TUNNEL_MTU);
-	if (value && strlen (value)) {
-		long int tmp;
-
-		errno = 0;
-		tmp = strtol (value, NULL, 10);
-		if (errno == 0 && tmp > 0 && tmp < 65536) {
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-
-			widget = glade_xml_get_widget (xml, "tunmtu_spinbutton");
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), (gdouble) tmp);
-			gtk_widget_set_sensitive (widget, TRUE);
-		}
-	} else {
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
-
-		widget = glade_xml_get_widget (xml, "tunmtu_spinbutton");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), 1500.0);
-		gtk_widget_set_sensitive (widget, FALSE);
-	}
-
-	widget = glade_xml_get_widget (xml, "fragment_checkbutton");
-	g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (fragment_toggled_cb), xml);
-
-	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_FRAGMENT_SIZE);
-	if (value && strlen (value)) {
-		long int tmp;
-
-		errno = 0;
-		tmp = strtol (value, NULL, 10);
-		if (errno == 0 && tmp > 0 && tmp < 65536) {
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-
-			widget = glade_xml_get_widget (xml, "fragment_spinbutton");
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), (gdouble) tmp);
-			gtk_widget_set_sensitive (widget, TRUE);
-		}
-	} else {
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
-
-		widget = glade_xml_get_widget (xml, "fragment_spinbutton");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), 1300.0);
-		gtk_widget_set_sensitive (widget, FALSE);
-	}
-
-	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_MSSFIX);
-	if (value && !strcmp (value, "yes")) {
-		widget = glade_xml_get_widget (xml, "mssfix_checkbutton");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-	}
-
 	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_COMP_LZO);
 	if (value && !strcmp (value, "yes")) {
 		widget = glade_xml_get_widget (xml, "lzo_checkbutton");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 	}
 
-	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_MSSFIX);
-	if (value && !strcmp (value, "yes")) {
-		widget = glade_xml_get_widget (xml, "mssfix_checkbutton");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-	}
-
 	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_PROTO_TCP);
 	if (value && !strcmp (value, "yes")) {
 		widget = glade_xml_get_widget (xml, "tcp_checkbutton");
@@ -1366,24 +1188,6 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_RENEG_SECONDS), g_strdup_printf ("%d", reneg_seconds));
 	}
 
-	widget = glade_xml_get_widget (xml, "tunmtu_checkbutton");
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
-		int tunmtu_size;
-
-		widget = glade_xml_get_widget (xml, "tunmtu_spinbutton");
-		tunmtu_size = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
-		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_TUNNEL_MTU), g_strdup_printf ("%d", tunmtu_size));
-	}
-
-	widget = glade_xml_get_widget (xml, "fragment_checkbutton");
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
-		int fragment_size;
-
-		widget = glade_xml_get_widget (xml, "fragment_spinbutton");
-		fragment_size = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
-		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_FRAGMENT_SIZE), g_strdup_printf ("%d", fragment_size));
-	}
-
 	widget = glade_xml_get_widget (xml, "port_checkbutton");
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
 		int port;
@@ -1397,10 +1201,6 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
 		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_COMP_LZO), g_strdup ("yes"));
 
-	widget = glade_xml_get_widget (xml, "mssfix_checkbutton");
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
-		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_MSSFIX), g_strdup ("yes"));
-
 	widget = glade_xml_get_widget (xml, "tcp_checkbutton");
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
 		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_PROTO_TCP), g_strdup ("yes"));
